==> kdepim-3.5.1.tar.bz2: kdepim-3.5.1/kaddressbook/kcmconfigs/kcmkabcustomfields.cpp <==
/*
    This file is part of KAddressbook.
    Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#include "kcmkabcustomfields.h"

#include "kabprefs.h"

#include <kstandarddirs.h>

#include <qregexp.h>

#include <kdepimmacros.h>

extern "C"
{
  KDE_EXPORT KCModule *create_kabcustomfields( QWidget *parent, const char * ) {
    return new KCMKabCustomFields( parent, "kcmkabcustomfields" );
  }
}

KCMKabCustomFields::KCMKabCustomFields( QWidget *parent, const char *name )
  : KCMDesignerFields( parent, name )
{
}

QString KCMKabCustomFields::localUiDir()
{
  return kabLocalDir() + "contacteditorpages/";
}

QString KCMKabCustomFields::uiPath()
{
  return "kaddressbook/contacteditorpages/";
}

void KCMKabCustomFields::writeActivePages( const QStringList &activePages )
{
  KABPrefs::instance()->setAdvancedCustomFields( activePages );
  KABPrefs::instance()->writeConfig();
}

QStringList KCMKabCustomFields::readActivePages()
{
  return KABPrefs::instance()->advancedCustomFields();
}

QString KCMKabCustomFields::applicationName()
{
  return "KADDRESSBOOK";
}

QString KCMKabCustomFields::kabLocalDir()
{
  QStringList kabdirs = locateLocal("data", "kaddressbook/");
  return kabdirs.grep( QRegExp( "^"+KGlobal::dirs()->localkdedir() ) ).first();
}

==> kdepim-4.1.3.tar.bz2: kdepim-4.1.3/kaddressbook/kcmconfigs/kcmkabcustomfields.cpp <==
/*
    This file is part of KAddressbook.
    Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#include "kcmkabcustomfields.h"

#include "kabprefs.h"

#include <kstandarddirs.h>

#include <QRegExp>

#include <kdemacros.h>
#include <kgenericfactory.h>


K_PLUGIN_FACTORY(KCMKabCustomFieldsFactory, registerPlugin<KCMKabCustomFields>();)
K_EXPORT_PLUGIN(KCMKabCustomFieldsFactory( "kcmkabcustomfields" ))


KCMKabCustomFields::KCMKabCustomFields( QWidget *parent, const QVariantList & )
  : KCMDesignerFields( KCMKabCustomFieldsFactory::componentData(), parent )
{
}

QString KCMKabCustomFields::localUiDir()
{
  return kabLocalDir() + "contacteditorpages/";
}

QString KCMKabCustomFields::uiPath()
{
  return "kaddressbook/contacteditorpages/";
}

void KCMKabCustomFields::writeActivePages( const QStringList &activePages )
{
  KABPrefs::instance()->setAdvancedCustomFields( activePages );
  KABPrefs::instance()->writeConfig();
}

QStringList KCMKabCustomFields::readActivePages()
{
  return KABPrefs::instance()->advancedCustomFields();
}

QString KCMKabCustomFields::applicationName()
{
  return "KADDRESSBOOK";
}

QString KCMKabCustomFields::kabLocalDir()
{
  QStringList kabdirs;
  kabdirs << KStandardDirs::locateLocal("data", "kaddressbook/");

  const QStringList results = kabdirs.filter( QRegExp( '^'+KGlobal::dirs()->localkdedir() ) );
  if ( !results.isEmpty() )
    return results.first();
  else
    return QString();
}
